#ifndef NT2_INCLUDE_CONSTANTS_THREEEPS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_THREEEPS_HPP_INCLUDED

#include <nt2/constant/include/constants/threeeps.hpp>

#endif
